# wordocx

A simple DOCX manipulation utility library.

## Installation

```sh
pip install wordocx
```

## Usage

```python
from wordocx import getComments  # Replace 'your_function' with actual functions from your library

# Example usage
comments = getComments('example.docx')
```

**requirements.txt**
```makefile
python-docx>=0.8.10
docx2python>=1.27.0
jsonlib-python3>=1.6.1
```
